@@ -1,4 +1,3 @@
-import json
 import ruamel.yaml
 import pathlib
 import fixate.config
@@ -31,39 +30,6 @@ def load_dict_config(in_dict: dict, config_name: str = "") -> None:
         fixate.config.__dict__.update(in_dict)
 
 
-def load_json_config(in_file, config_name=None) -> None:
-    """
-    :param in_file:
-     valid open file like such as
-        open(in_file) as f:
-            load_json_config(f)
-     or stringio instance
-    :param config_name:
-     optional way of grouping the config details
-    :usage
-     my_json_file
-     {
-        "HI": "WORLD"
-     }
-     config_name = None
-     >>> import fixate.config
-     >>> with open("my_json_file") as f:
-     >>>    load_json_config("my_json_file")
-     >>> print(fixate.config.HI)
-     "WORLD"
-     config_name = "My_Json"
-     >>> import fixate.config
-     >>> with open("my_json_file") as f:
-     >>>    load_json_config("my_json_file", "My_Json")
-     >>> print(fixate.config.My_Json)
-     {"HI": "WORLD"}
-    """
-    if config_name:
-        fixate.config.__dict__.update({config_name: json.load(in_file)})
-    else:
-        fixate.config.__dict__.update(json.load(in_file))
-
-
 def load_yaml_config(yaml_in: str) -> None:
     """
     :param in_file:
