@@ -4,20 +4,12 @@ import time
 import os
 from fixate.core.common import bits
 from fixate.core.exceptions import InstrumentNotConnected
-import fixate.config
-import fixate.core.discover
 
 
 def open(ftdi_description=""):
-    """Open is the public api for the bit bang driver for discovering and opening a connection
-    to a valid bit bang device
-    :param restrictions:
-    A dictionary containing the extents of the required equipment
-    :return:
-    A instantiated class connected to a valid bit_bang class
-    """
-    devices = fixate.core.discover.discover_ftdi()
-    for dev in devices:
+    create_device_info_list()
+
+    for dev in get_device_info_list():
         if ftdi_description.encode() == dev.Description or ftdi_description == "":
             return FTDI2xx(dev.Description)
     raise InstrumentNotConnected(
@@ -297,12 +289,12 @@ class FTDI2xx(object):
 
     def write_bit_mode(self, mask, validate=False):
         """
-            handle; gained from device info
-            mask; value to write for the mask
-                for BIT_MODE.FT_BITMODE_CBUS_BITBANG
-                upper nibble is input (0) output (1)
-                lower nibble is pin value low (0) high (1)
-            bit_mode; Type BIT_MODE
+        handle; gained from device info
+        mask; value to write for the mask
+            for BIT_MODE.FT_BITMODE_CBUS_BITBANG
+            upper nibble is input (0) output (1)
+            lower nibble is pin value low (0) high (1)
+        bit_mode; Type BIT_MODE
         """
         check_return(ftdI2xx.FT_SetBitMode(self.handle, UCHAR(mask), self.bit_mode))
         data_bus = UCHAR()
