@@ -1,25 +1,10 @@
 from abc import ABCMeta, abstractmethod
 from fixate.core.exceptions import InstrumentFeatureUnavailable
-from fixate.core.discover import open_instrument
 import inspect
 
-try:
-    import typing
+import typing
 
-    number = typing.Union[float, int]
-except ImportError:
-    number = float
-
-
-def open():
-    """Open is the public api for the dmm driver for discovering and opening a connection
-    to a valid Digital Multimeter
-    :param restrictions:
-    A dictionary containing the extents of the required equipment
-    :return:
-    A instantiated class connected to a valid funcgen
-    """
-    return open_instrument("FUNC_GEN")
+number = typing.Union[float, int]
 
 
 class Waveform:
@@ -154,34 +139,6 @@ class Sync:
         self._call(output)
 
 
-# class TriggerSource:
-#     def immediate(self):
-#         raise InstrumentFeatureUnavailable(
-#             "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-#
-#     def external(self):
-#         raise InstrumentFeatureUnavailable(
-#             "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-#
-#     def manual(self):
-#         raise InstrumentFeatureUnavailable(
-#             "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-#
-#     def timer(self):
-#         raise InstrumentFeatureUnavailable(
-#             "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-
-
-# class TriggerEdge:
-#     def rising(self):
-#         raise InstrumentFeatureUnavailable(
-#             "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-#
-#     def falling(self):
-#         raise InstrumentFeatureUnavailable(
-#             "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-
-
 class TriggerOut:
     def __call__(self):
         self._call()
@@ -235,14 +192,6 @@ class Trigger:
             )
         )
 
-    # def external(self):  # Turn into class
-    #     raise InstrumentFeatureUnavailable(
-    #         "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-    #
-    # def manual(self):  # Turn into class
-    #     raise InstrumentFeatureUnavailable(
-    #         "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-
     def timer(self, seconds: number):
         raise InstrumentFeatureUnavailable(
             "{} not available on this device".format(
@@ -417,10 +366,6 @@ class ModulateFM:
             )
         )
 
-        # def frequency(self, value: number):
-        #     raise InstrumentFeatureUnavailable(
-        #         "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-
 
 class ModulatePM:
     def __call__(self):
@@ -641,10 +586,6 @@ class ChannelBase:
             )
         )
 
-        # def output(self, value: bool):
-        #     raise InstrumentFeatureUnavailable(
-        #         "{} not available on this device".format(inspect.currentframe().f_code.co_name))
-
 
 class Load:
     def __call__(self, ohms: number):
