@@ -6,41 +6,17 @@ from functools import update_wrapper
 import inspect
 
 MODES = {
-    ":SINusoid": {
-        " [{frequency}]": {
-            ",[{amplitude}]": {
-                ",[{offset}]": {}}}},
-    ":SQUare": {
-        " [{frequency}]": {
-            ",[{amplitude}]": {
-                ",[{offset}]": {}}}},
-    ":RAMP": {
-        " [{frequency}]": {
-            ",[{amplitude}]": {
-                ",[{offset}]": {}}}},
-    ":PULSE": {
-        " [{frequency}]": {
-            ",[{amplitude}]": {
-                ",[{offset}]": {}}}},
-    ":NOISe DEFault": {
-        ",[{amplitude}]": {
-            ",[{offset}]": {}}},
-    ":DC DEFault,DEFault": {
-        ",[{offset}]": {}},
-    ":PRBS": {
-        " [{frequency}]": {
-            ",[{amplitude}]": {
-                ",[{offset}]": {}}}},
-    ":ARB": {
-        " [{frequency}]": {
-            ",[{amplitude}]": {
-                ",[{offset}]": {}}}}
+    ":SINusoid": {" [{frequency}]": {",[{amplitude}]": {",[{offset}]": {}}}},
+    ":SQUare": {" [{frequency}]": {",[{amplitude}]": {",[{offset}]": {}}}},
+    ":RAMP": {" [{frequency}]": {",[{amplitude}]": {",[{offset}]": {}}}},
+    ":PULSE": {" [{frequency}]": {",[{amplitude}]": {",[{offset}]": {}}}},
+    ":NOISe DEFault": {",[{amplitude}]": {",[{offset}]": {}}},
+    ":DC DEFault,DEFault": {",[{offset}]": {}},
+    ":PRBS": {" [{frequency}]": {",[{amplitude}]": {",[{offset}]": {}}}},
+    ":ARB": {" [{frequency}]": {",[{amplitude}]": {",[{offset}]": {}}}},
 }
 
-ADV_MODES = {
-    ':SQUare:'
-    'DCYCle'
-}
+ADV_MODES = {":SQUare:" "DCYCle"}
 
 
 class Keysight33500B(FuncGen):
@@ -74,27 +50,67 @@ class Keysight33500B(FuncGen):
         # Rigol Restrictions
         self.__restr_bandwidth = {"min": unit_scale("4uHz"), "max": unit_scale("20MHz")}
         self.__restr_phase = {"min": -180, "max": 180}
-        self.__restr_amplitude = {"min": unit_scale("4mVpp"), "max": unit_scale("20Vpp")}
+        self.__restr_amplitude = {
+            "min": unit_scale("4mVpp"),
+            "max": unit_scale("20Vpp"),
+        }
         self._amplitude = None
         self._store = {"ch1_duty": "50", "ch2_duty": "50", "ch1_modulate_source": "INT"}
 
         self.api = [
-
             # waveform selection
             # Channel 1:
-            ("channel1.waveform.sin", self.store_and_write, ("SOUR1:FUNC SIN", {"ch1_waveform_handler": None})),
-            ("channel1.waveform.square", self.store_and_write,
-             ("SOUR1:FUNC SQU\r\nSOUR1:FUNC:SQU:DCYC {self._store[ch1_duty]}",
-              {"ch1_waveform_handler": "channel1.waveform.square"})),
-            ("channel1.waveform.ramp", self.store_and_write, ("SOUR1:FUNC RAMP", {"ch1_waveform_handler": None})),
-            ("channel1.waveform.pulse", self.store_and_write,
-             ("SOUR1:FUNC PULS\r\nPULS:DCYC {self._store[ch1_duty]}",
-              {"ch1_waveform_handler": "channel1.waveform.pulse"})),
-            ("channel1.waveform.arb", self.store_and_write, ("SOUR1:FUNC  ARB", {"ch1_waveform_handler": None})),
-            ("channel1.waveform.triangle", self.store_and_write, ("SOUR1:FUNC TRI", {"ch1_waveform_handler": None})),
-            ("channel1.waveform.noise", self.store_and_write, ("SOUR1:FUNC NOIS", {"ch1_waveform_handler": None})),
-            ("channel1.waveform.dc", self.store_and_write, ("SOUR1:FUNC DC", {"ch1_waveform_handler": None})),
-            ("channel1.waveform.prbs", self.store_and_write, ("SOUR1:FUNC PRBS", {"ch1_waveform_handler": None})),
+            (
+                "channel1.waveform.sin",
+                self.store_and_write,
+                ("SOUR1:FUNC SIN", {"ch1_waveform_handler": None}),
+            ),
+            (
+                "channel1.waveform.square",
+                self.store_and_write,
+                (
+                    "SOUR1:FUNC SQU\r\nSOUR1:FUNC:SQU:DCYC {self._store[ch1_duty]}",
+                    {"ch1_waveform_handler": "channel1.waveform.square"},
+                ),
+            ),
+            (
+                "channel1.waveform.ramp",
+                self.store_and_write,
+                ("SOUR1:FUNC RAMP", {"ch1_waveform_handler": None}),
+            ),
+            (
+                "channel1.waveform.pulse",
+                self.store_and_write,
+                (
+                    "SOUR1:FUNC PULS\r\nPULS:DCYC {self._store[ch1_duty]}",
+                    {"ch1_waveform_handler": "channel1.waveform.pulse"},
+                ),
+            ),
+            (
+                "channel1.waveform.arb",
+                self.store_and_write,
+                ("SOUR1:FUNC  ARB", {"ch1_waveform_handler": None}),
+            ),
+            (
+                "channel1.waveform.triangle",
+                self.store_and_write,
+                ("SOUR1:FUNC TRI", {"ch1_waveform_handler": None}),
+            ),
+            (
+                "channel1.waveform.noise",
+                self.store_and_write,
+                ("SOUR1:FUNC NOIS", {"ch1_waveform_handler": None}),
+            ),
+            (
+                "channel1.waveform.dc",
+                self.store_and_write,
+                ("SOUR1:FUNC DC", {"ch1_waveform_handler": None}),
+            ),
+            (
+                "channel1.waveform.prbs",
+                self.store_and_write,
+                ("SOUR1:FUNC PRBS", {"ch1_waveform_handler": None}),
+            ),
             # Channel Configuration
             # Channel 1:
             ("channel1.vrms", self.write, "SOUR1:VOLT:UNIT VRMS\r\nVOLT {value}"),
@@ -102,7 +118,11 @@ class Keysight33500B(FuncGen):
             ("channel1.dbm", self.write, "SOUR1:VOLT:UNIT DBM\r\nVOLT {value}"),
             ("channel1.offset", self.write, "SOUR1:VOLT:OFFS {value}"),
             ("channel1.phase", self.write, "SOUR1:PHAS {value}"),
-            ("channel1.duty", self.store_and_execute, ({"ch1_duty": "{value}"}, "ch1_waveform_handler")),
+            (
+                "channel1.duty",
+                self.store_and_execute,
+                ({"ch1_duty": "{value}"}, "ch1_waveform_handler"),
+            ),
             ("channel1.frequency", self.write, "SOUR1:FREQ {value}"),
             # Channel Activation
             ("channel1._call", self.write, "OUTP {value}"),
@@ -115,8 +135,16 @@ class Keysight33500B(FuncGen):
             # Trigger Configuration
             ("trigger.immediate", self.write, "TRIG1:SOUR IMM"),
             ("trigger.external._call", self.write, "TRIG1:SOUR EXT"),
-            ("trigger.external.rising", self.write, "TRIG1:SOUR EXT\r\n TRIG1:SLOP POS"),
-            ("trigger.external.falling", self.write, "TRIG1:SOUR EXT\r\n TRIG1:SLOP NEG"),
+            (
+                "trigger.external.rising",
+                self.write,
+                "TRIG1:SOUR EXT\r\n TRIG1:SLOP POS",
+            ),
+            (
+                "trigger.external.falling",
+                self.write,
+                "TRIG1:SOUR EXT\r\n TRIG1:SLOP NEG",
+            ),
             ("trigger.manual._call", self.write, "TRIG1:SOUR BUS"),
             ("trigger.manual.initiate", self.write, "TRIG1:SOUR BUS"),
             ("trigger.timer", self.write, "TRIG:SOUR TIM\r\n TRIG1:TIM {seconds}"),
@@ -127,22 +155,55 @@ class Keysight33500B(FuncGen):
             ("trigger.out.falling", self.write, "OUTP:TRIG ON\r\n OUTP:TRIG:SLOP NEG"),
             # Modulate
             # Channel 1:
-            ("channel1.modulate.am._call", self.store, {"ch1_modulate_state": "AM", "ch1_modulate_setting": "FREQ"}),
-            ("channel1.modulate.fm._call", self.store, {"ch1_modulate_state": "FM", "ch1_modulate_setting": "FREQ"}),
-            ("channel1.modulate.pm._call", self.store, {"ch1_modulate_state": "PM", "ch1_modulate_setting": "FREQ"}),
-            ("channel1.modulate.fsk._call", self.store, {"ch1_modulate_state": "FSK", "ch1_modulate_setting": "RATE"}),
             (
-            "channel1.modulate.bpsk._call", self.store, {"ch1_modulate_state": "BPSK", "ch1_modulate_setting": "RATE"}),
-            ("channel1.modulate.sum._call", self.store, {"ch1_modulate_state": "SUM", "ch1_modulate_setting": "FREQ"}),
+                "channel1.modulate.am._call",
+                self.store,
+                {"ch1_modulate_state": "AM", "ch1_modulate_setting": "FREQ"},
+            ),
+            (
+                "channel1.modulate.fm._call",
+                self.store,
+                {"ch1_modulate_state": "FM", "ch1_modulate_setting": "FREQ"},
+            ),
+            (
+                "channel1.modulate.pm._call",
+                self.store,
+                {"ch1_modulate_state": "PM", "ch1_modulate_setting": "FREQ"},
+            ),
+            (
+                "channel1.modulate.fsk._call",
+                self.store,
+                {"ch1_modulate_state": "FSK", "ch1_modulate_setting": "RATE"},
+            ),
+            (
+                "channel1.modulate.bpsk._call",
+                self.store,
+                {"ch1_modulate_state": "BPSK", "ch1_modulate_setting": "RATE"},
+            ),
+            (
+                "channel1.modulate.sum._call",
+                self.store,
+                {"ch1_modulate_state": "SUM", "ch1_modulate_setting": "FREQ"},
+            ),
             # MODULATE SOURCES:
-            ("channel1.modulate.source.internal._call", self.write, "SOUR1:{self._store[ch1_modulate_state]}:"
-                                                                    "SOUR INT"),
-            ("channel1.modulate.source.external", self.write, "SOUR1:{self._store[ch1_modulate_state]}:SOUR EXT"),
+            (
+                "channel1.modulate.source.internal._call",
+                self.write,
+                "SOUR1:{self._store[ch1_modulate_state]}:" "SOUR INT",
+            ),
+            (
+                "channel1.modulate.source.external",
+                self.write,
+                "SOUR1:{self._store[ch1_modulate_state]}:SOUR EXT",
+            ),
             # MODULATE ACTIVATION:
             # Channel 1:
-            ("channel1.modulate._call", self.write,
-             "{self._store[ch1_modulate_state]}:SOUR {self._store[ch1_modulate_source]}\r\n"
-             "{self._store[ch1_modulate_state]}:STAT {value}"),
+            (
+                "channel1.modulate._call",
+                self.write,
+                "{self._store[ch1_modulate_state]}:SOUR {self._store[ch1_modulate_source]}\r\n"
+                "{self._store[ch1_modulate_state]}:STAT {value}",
+            ),
             # MODULATE OPTIONS:
             # Channel 1:
             ("channel1.modulate.am.depth", self.write, "SOUR1:AM:DEPT {value}"),
@@ -151,41 +212,75 @@ class Keysight33500B(FuncGen):
             ("channel1.modulate.pm.phase_dev", self.write, "SOUR1:PM:DEV {value}"),
             ("channel1.modulate.fsk.hop_freq", self.write, "SOUR1:FSK:FREQ {value}"),
             ("channel1.modulate.fsk.rate", self.write, "SOUR1:FSK:INT:RATE {value}"),
-            ("channel1.modulate.sum.modulate_percent", self.write, "SOUR1:SUM:AMPL {percent}"),
+            (
+                "channel1.modulate.sum.modulate_percent",
+                self.write,
+                "SOUR1:SUM:AMPL {percent}",
+            ),
             # Internal
-            ("channel1.modulate.source.internal.shape.sin", self.write,
-             "{self._store[ch1_modulate_state]}:INT:FUNC SIN"),
-            ("channel1.modulate.source.internal.shape.square", self.write,
-             "{self._store[ch1_modulate_state]}:INT:FUNC SQU"),
-            ("channel1.modulate.source.internal.shape.triangle", self.write,
-             "{self._store[ch1_modulate_state]}:INT:FUNC TRI"),
-            ("channel1.modulate.source.internal.shape.up_ramp", self.write,
-             "{self._store[ch1_modulate_state]}:INT:FUNC RAMP"),
-            ("channel1.modulate.source.internal.shape.down_ramp", self.write,
-             "{self._store[ch1_modulate_state]}:INT:FUNC NRAMP"),
-            ("channel1.modulate.source.internal.shape.noise", self.write,
-             "{self._store[ch1_modulate_state]}:INT:FUNC NOIS"),
+            (
+                "channel1.modulate.source.internal.shape.sin",
+                self.write,
+                "{self._store[ch1_modulate_state]}:INT:FUNC SIN",
+            ),
+            (
+                "channel1.modulate.source.internal.shape.square",
+                self.write,
+                "{self._store[ch1_modulate_state]}:INT:FUNC SQU",
+            ),
+            (
+                "channel1.modulate.source.internal.shape.triangle",
+                self.write,
+                "{self._store[ch1_modulate_state]}:INT:FUNC TRI",
+            ),
+            (
+                "channel1.modulate.source.internal.shape.up_ramp",
+                self.write,
+                "{self._store[ch1_modulate_state]}:INT:FUNC RAMP",
+            ),
+            (
+                "channel1.modulate.source.internal.shape.down_ramp",
+                self.write,
+                "{self._store[ch1_modulate_state]}:INT:FUNC NRAMP",
+            ),
+            (
+                "channel1.modulate.source.internal.shape.noise",
+                self.write,
+                "{self._store[ch1_modulate_state]}:INT:FUNC NOIS",
+            ),
             # Modulate Frequency
-            ("channel1.modulate.source.internal.frequency", self.write,
-             "SOUR1:{self._store[ch1_modulate_state]}:INT:{self._store[ch1_modulate_setting]} {value}"),
-
+            (
+                "channel1.modulate.source.internal.frequency",
+                self.write,
+                "SOUR1:{self._store[ch1_modulate_state]}:INT:{self._store[ch1_modulate_setting]} {value}",
+            ),
             # LOAD:
             # channel1:
             ("channel1.load._call", self.write, "OUTP1:LOAD {ohms}"),
             ("channel1.load.infinite", self.write, "OUTP1:LOAD INF"),
-
             # BURST
             # Channel 1:
             ("channel1.burst.gated._call", self.write, "SOUR1:BURS:MODE GAT"),
             ("channel1.burst._call", self.write, "SOUR1:BURS:STAT {value}"),
             ("channel1.burst.ncycle._call", self.write, "SOUR1:BURS:MODE TRIG"),
-            ("channel1.burst.ncycle.cycles._call", self.write, "SOUR1:BURS:NCYC {cycles}"),
-            ("channel1.burst.ncycle.cycles.infinite", self.write, "SOUR1:BURS:NCYC INF"),
-            ("channel1.burst.ncycle.burst_period", self.write, "SOUR1:BURS:INT:PER {seconds}"),
+            (
+                "channel1.burst.ncycle.cycles._call",
+                self.write,
+                "SOUR1:BURS:NCYC {cycles}",
+            ),
+            (
+                "channel1.burst.ncycle.cycles.infinite",
+                self.write,
+                "SOUR1:BURS:NCYC INF",
+            ),
+            (
+                "channel1.burst.ncycle.burst_period",
+                self.write,
+                "SOUR1:BURS:INT:PER {seconds}",
+            ),
             ("channel1.burst.gated.positive", self.write, "SOUR1:BURS:GATE:POL NORM"),
             ("channel1.burst.gated.negative", self.write, "SOUR1:BURS:GATE:POL INV"),
             ("channel1.burst.phase", self.write, "SOUR1:BURS:PHAS {degrees}"),
-
         ]
 
         # ----------------------------------------------------------------------------------------------------------------------
@@ -244,7 +339,7 @@ class Keysight33500B(FuncGen):
 
     def _check_errors(self):
         resp = self.instrument.query("SYST:ERR?")
-        code, msg = resp.strip('\n').split(',')
+        code, msg = resp.strip("\n").split(",")
         code = int(code)
         msg = msg.strip('"')
         return code, msg
@@ -261,15 +356,22 @@ class Keysight33500B(FuncGen):
             if silent:
                 return errors
             else:
-                raise InstrumentError("Error(s) Returned from FuncGen\n" +
-                                      "\n".join(["Code: {}\nMessage:{}".format(code, msg) for code, msg in errors]))
+                raise InstrumentError(
+                    "Error(s) Returned from FuncGen\n"
+                    + "\n".join(
+                        [
+                            "Code: {}\nMessage:{}".format(code, msg)
+                            for code, msg in errors
+                        ]
+                    )
+                )
 
     def write(self, base_str, *args, **kwargs):
         formatted_string = self._format_string(base_str, **kwargs)
         self._write(formatted_string)
 
     def _format_string(self, base_str, **kwargs):
-        kwargs['self'] = self
+        kwargs["self"] = self
         prev_string = base_str
         cur_string = ""
         while True:
@@ -345,4 +447,19 @@ class Keysight33500B(FuncGen):
             # handler(self, new_str)
             return handler(base_str, **nkwargs)
 
-        return update_wrapper(temp_func, func)
\ No newline at end of file
+        return update_wrapper(temp_func, func)
+
+    def get_identity(self) -> str:
+        """
+        Identification string contains four comma separated fields:
+              Manufacturer name, Model number, Serial number, Revision code
+        :return:
+        Identification string is in the following format for the 33500 Series instruments:
+            Keysight Technologies,[Model Number],[10-char Serial Number],A.aaa-B.bb-C.cc-DD-EE
+                A.aaa = Firmware revision
+                B.bb = Front panel FW revision
+                C.cc = Power supply controller FW revision
+                DD = FPGA revision
+                EE = PCBA revision
+        """
+        return self.instrument.query("*IDN?").strip()
