@@ -7,7 +7,7 @@ from collections import OrderedDict
 import os.path
 from queue import Queue
 from PyQt5 import QtCore, QtGui, QtWidgets
-from PyQt5.QtCore import QObject, QThread, pyqtSignal, Qt
+from PyQt5.QtCore import QObject, QThread, pyqtSignal, Qt, QRectF
 from pubsub import pub
 import fixate.config
 from fixate.config import RESOURCES
@@ -55,7 +55,7 @@ def get_status_colours(status):
 
 class SequencerThread(QObject):
     def __init__(self, worker, completion_callback):
-        super(QObject, self).__init__()
+        super().__init__()
         self.worker = worker
         self.completion_callback = completion_callback
 
@@ -91,6 +91,7 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
     sig_history_update = pyqtSignal(str)
     # Image Window
     sig_image_update = pyqtSignal(str)
+    sig_gif_update = pyqtSignal(str)
     sig_image_clear = pyqtSignal()
 
     # Progress Signals
@@ -177,6 +178,7 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
         self.sig_error_clear.connect(self.on_error_clear)
         self.sig_history_update.connect(self.on_history_update)
         self.sig_image_update.connect(self.on_image_update)
+        self.sig_gif_update.connect(self.on_gif_update)
         self.sig_image_clear.connect(self.on_image_clear)
         self.sig_button_reset.connect(self.on_button_reset)
         self.sig_progress_set_max.connect(self.on_progress_set_max)
@@ -195,6 +197,7 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
 
         # Image Window
         pub.subscribe(self._topic_UI_image, "UI_image")
+        pub.subscribe(self._topic_UI_gif, "UI_gif")
         pub.subscribe(self._topic_UI_image_clear, "UI_image_clear")
 
         pub.subscribe(self._topic_Test_Start, "Test_Start")
@@ -251,6 +254,9 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
     def _topic_UI_image(self, path):
         self.sig_image_update.emit(path)
 
+    def _topic_UI_gif(self, path):
+        self.sig_gif_update.emit(path)
+
     def on_image_update(self, path):
         """
         Adds an image to the image viewer. These images can be stacked with transparent layers to form overlays
@@ -269,6 +275,65 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
             image = QtGui.QPixmap()
             image.loadFromData(image_data)
             self.image_scene.addPixmap(image)
+
+            if any(
+                [
+                    isinstance(x, QtWidgets.QGraphicsProxyWidget)
+                    for x in self.image_scene.items()
+                ]
+            ):
+                # If any gifs -  need to reset the window to allow auto adjust
+                self.image_scene.setSceneRect(QRectF())
+
+            self.ImageView.fitInView(
+                0,
+                0,
+                self.image_scene.width(),
+                self.image_scene.height(),
+                QtCore.Qt.KeepAspectRatio,
+            )
+
+    def on_gif_update(self, path):
+        """
+        Adds a gif to the image scene and start playing.
+        :param path: Relative path to gif within the test scripts package
+        :return: None
+        """
+        try:
+            image_data = pkgutil.get_data("module.loaded_tests", path)
+        except (FileNotFoundError, OSError):
+            # When running direct from the file system, if an image isn't found we
+            # get FileNotFoundError. When running from a zip file, we get OSError
+            logger.exception("Image path specific in the test script was invalid")
+            # message dialog so the user knows the image didn't load
+            self.file_not_found(path)
+        else:
+            # Remove any images/gifs from image scene
+            if self.image_scene.items():
+                logger.error("Unsupported behaviour when overlaying .gifs")
+                self.image_scene.clear()  # clear the scene
+
+            animation = QtWidgets.QLabel()
+            image_qbytes = QtCore.QByteArray(image_data)
+            gif_buffer = QtCore.QBuffer(image_qbytes)
+            gif_buffer.open(QtCore.QIODevice.OpenModeFlag.ReadOnly)
+            movie = QtGui.QMovie(gif_buffer, QtCore.QByteArray(b"gif"))
+            movie.setCacheMode(QtGui.QMovie.CacheMode.CacheAll)
+
+            if movie.isValid():
+                animation.setMovie(movie)
+                self.image_scene.addWidget(animation)
+                # Random fix to force proper caching:
+                # https://stackoverflow.com/questions/71072485/qmovie-from-qbuffer-from-qbytearray-not-displaying-gif
+                movie.jumpToFrame(movie.frameCount() - 1)
+                movie.start()
+                # Need to force the window size as doesn't detect movie inside label
+                self.image_scene.setSceneRect(QRectF(movie.frameRect()))
+            else:
+                logger.error("Unable to load animation: %s", path)
+                # Let the user know that animation is missing
+                self.warning_box("Unable to load animation!")
+
             self.ImageView.fitInView(
                 0,
                 0,
@@ -281,7 +346,11 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
         self.sig_image_clear.emit()
 
     def on_image_clear(self):
-        self.image_scene.clear()
+        """Create a fresh graphics scene"""
+        # NOTE image_scene.clear() does not remove all properties as desired
+        self.image_scene = QtWidgets.QGraphicsScene()
+        self.ImageView.set_scene(self.image_scene)
+        self.ImageView.setScene(self.image_scene)
 
     def file_not_found(self, path):
         """
@@ -298,6 +367,21 @@ class FixateGUI(QtWidgets.QMainWindow, layout.Ui_FixateUI):
         self.dialog.setIcon(QtWidgets.QMessageBox.Warning)
         self.dialog.exec()
 
+    def warning_box(self, msg: str):
+        """
+        Display warning box with message
+        :param msg: message to display
+        :return:
+        """
+
+        self.dialog = QtWidgets.QMessageBox()
+        self.dialog.setText("Warning!")
+        self.dialog.setInformativeText(msg)
+        self.dialog.setStandardButtons(QtWidgets.QMessageBox.Ok)
+        self.dialog.setDefaultButton(QtWidgets.QMessageBox.Ok)
+        self.dialog.setIcon(QtWidgets.QMessageBox.Warning)
+        self.dialog.exec()
+
     def on_tree_init(self, tree):
 
         # Make sure this function is only run once
